using System.Collections.Generic;
using System.Diagnostics;
using System.Windows.Input;
using Books.Core.Services;
using Cirrious.CrossCore.Platform;
using Cirrious.MvvmCross.ViewModels;

namespace Books.Core.ViewModels
{
    public class FirstViewModel
        : MvxViewModel
    {


        private readonly IBooksService booksService;

        public FirstViewModel(IBooksService booksService, IMvxTrace trace)
        {
            this.booksService = booksService;
            SearchCommand = new MvxCommand(update,()=>!IsLoading);
        }

        private bool isLoading;

        public bool IsLoading
        {
            get { return isLoading; }
            set
            {
                isLoading = value;
                RaisePropertyChanged(() => IsLoading);
            }
        }

        private string searchTerm;

        public string SearchTerm
        {
            get { return searchTerm; }
            set
            {
                searchTerm = value;
                RaisePropertyChanged(() => SearchTerm);
            }
        }

        private List<BookSearchItem> results;

        public List<BookSearchItem> Results
        {
            get { return results; }
            private set { results = value; RaisePropertyChanged(() => Results); }
        }

        private void update()
        {
            IsLoading = true;
                if (string.IsNullOrWhiteSpace(searchTerm)) return;
                booksService.StartSearchAsync(SearchTerm,
                                              result => { Results = result.items;
                                                            IsLoading = false;
                                              },
                                              ex => { MvxTrace.Error(ex.Message);
                                                        IsLoading = false;
                                              });
        }

        public ICommand SearchCommand { get; private set; }
    }
}
